@@ -34,6 +34,12 @@ static PyObject* ObjectId;
 static PyObject* DBRef;
 static PyObject* RECompile;
 
+#if PY_VERSION_HEX < 0x02050000 && !defined(PY_SSIZE_T_MIN)
+typedef int Py_ssize_t;
+#define PY_SSIZE_T_MAX INT_MAX
+#define PY_SSIZE_T_MIN INT_MIN
+#endif
+
 static char* shuffle_oid(const char* oid) {
     char* shuffled = (char*) malloc(12);
 
